<?php
/**
 * Plugin Name: Aurora Heatmap
 * Plugin URI:  https://market.seous.info/aurora-heatmap
 * Description: Beautiful like an aurora! A simple WordPress heatmap that can be completed with just a plugin.
 * Version:     1.3.4
 * Author:      R3098
 * Author URI:  https://seous.info/
 * License:     GPLv2
 * Text Domain: aurora-heatmap
 * Domain Path: /languages
 *
 * @package aurora-heatmap
 * @copyright 2019-2020 R3098 <info@seous.info>
 * @version 1.3.4
  */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'aurora_heatmap_conflict' ) ) {
	function aurora_heatmap_conflict() {
		die( esc_html__( 'Fail to activate. Another version of Aurora Heatmap is already active.', 'aurora-heatmap' ) );
	}
}

// Check conflict.
if ( defined( 'AURORA_HEATMAP' ) ) {
	if ( is_admin() ) {
		register_activation_hook( __FILE__, 'aurora_heatmap_conflict' );
	}
	return;
} else {
	// Set constant to check conflict.
	define( 'AURORA_HEATMAP', plugin_basename( __FILE__ ) );
}

function() {
	// Translation for plugin headers.
	__( 'Aurora Heatmap', 'aurora-heatmap' );
	__( 'Beautiful like an aurora! A simple WordPress heatmap that can be completed with just a plugin.', 'aurora-heatmap' );
	// Translation for premium version.
	_x( 'Due to unlicensed or expired licenses, the premium version features, including <b>premium version plugin updates</b>, are limited.', 'Free Plan', 'aurora-heatmap' );
	// translators: %1$s: URL of Upgrade in this plugin.
	// translators: %2$s: URL of Aurora Heatmap Plugin on the WordPress.org.
	// translators: %3$s: URL of Help in this plugin.
	_x( 'To use the latest version, we recommend the <a href="%1$s">lisense agreement</a> or the <a href="%2$s">free version</a>. See the <a href="%3$s">help</a> for details.', 'Free Plan', 'aurora-heatmap' );
	_x( 'About the free plan', 'Free Plan', 'aurora-heatmap' );
	_x( 'The license has expired, but the free plan can still be used.', 'Free Plan', 'aurora-heatmap' );
	_x( 'However, it is not possible to update to the latest version of the premium version, so we recommend that you replace the WordPress.org plugin directory with the free version.', 'Free Plan', 'aurora-heatmap' );
	_x( 'It is also possible to take over the current data.', 'Free Plan', 'aurora-heatmap' );

	_x( 'Migrate data to the free version', 'Free Plan', 'aurora-heatmap' );
	_x( '<b>Stop</b> the premium version plugin.', 'Free Plan', 'aurora-heatmap' );
	_x( '<b>Install</b> / <b>activate</b> <a href="plugin-install.php?s=aurora-heatmap&tab=search&type=term">the free version</a> plugin.', 'Free Plan', 'aurora-heatmap' );
	_x( '<b>Delete</b> the premium version plugin.', 'Free Plan', 'aurora-heatmap' );

	_x( 'If you can\'t receive authentication email', 'Free Plan', 'aurora-heatmap' );
	// translators: %s: Your Profile.
	_x( 'Change the email address of <a href="profile.php">%s</a> and restart the user registration with the following button.', 'Free Plan', 'aurora-heatmap' );
	_x( 'Restart the user registration', 'Free Plan', 'aurora-heatmap' );
};

if ( ! function_exists( 'aurora_heatmap_uninstall' ) ) {
	function aurora_heatmap_uninstall() {
		// If installed two or more, keep tables and options.
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
		$installed = 0;
		foreach ( array_keys( get_plugins() ) as $plugin ) {
			if ( 'aurora-heatmap.php' !== basename( $plugin ) ) {
				continue;
			}
			$installed++;
			if ( 1 < $installed ) {
				return;
			}
		}

		// Delete option, cron, DB tables.
		global $wpdb;
		delete_option( 'aurora_heatmap_option' );
		wp_clear_scheduled_hook( 'aurora_heatmap_cron_daily' );
		$wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}ahm_events" );
		$wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}ahm_pages" );
	}
}

require_once __DIR__ . '/class-aurora-heatmap-options.php';
require_once __DIR__ . '/class-aurora-heatmap-basic.php';

if ( is_file( __DIR__ . '/aurora-heatmap__premium_only.php' ) ) {
	require_once __DIR__ . '/aurora-heatmap__premium_only.php';
} else {
	if ( is_admin() ) {
		register_activation_hook( __FILE__, "Aurora_Heatmap_Basic::activation" );
		register_deactivation_hook( __FILE__, "Aurora_Heatmap_Basic::deactivation" );
		register_uninstall_hook( __FILE__, 'aurora_heatmap_uninstall' );
	}

	function aurora_heatmap_init() {
		new Aurora_Heatmap_Basic();
	}

	add_action( 'init', 'aurora_heatmap_init' );
}

/* vim: set ts=4 sw=4 sts=4 noet: */
